Module: Auth::Sanitizer::FilteredAttributes::ClassMethods

Defined in:
lib/auth/sanitizer/filtered_attributes.rb

Overview

Class-level helpers for configuring filtered attributes.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.filtered_attribute_names(base) ⇒ Array<Symbol>

The configured attribute names to filter.

Parameters:

  • base (Class)

    The class to get filtered attributes for

Returns:

  • (Array<Symbol>)


60
61
62
63
64
# File 'lib/auth/sanitizer/filtered_attributes.rb', line 60

def filtered_attribute_names(base)
  return [] unless base.instance_variable_defined?(:@filtered_attribute_names)

  base.instance_variable_get(:@filtered_attribute_names) || []
end

.filtered_attributes(base, *attributes) ⇒ void

This method returns an undefined value.

Declare attributes that should be redacted in inspect output.

Parameters:

  • attributes (Array<Symbol, String>)

    One or more attribute names



52
53
54
# File 'lib/auth/sanitizer/filtered_attributes.rb', line 52

def filtered_attributes(base, *attributes)
  base.instance_variable_set(:@filtered_attribute_names, attributes.map(&:to_sym))
end

Instance Method Details

#filtered_attribute_namesArray<Symbol>

The configured attribute names to filter.

Returns:

  • (Array<Symbol>)


78
79
80
# File 'lib/auth/sanitizer/filtered_attributes.rb', line 78

def filtered_attribute_names
  ClassMethods.filtered_attribute_names(self)
end

#filtered_attributes(*attributes) ⇒ void

This method returns an undefined value.

Declare attributes that should be redacted in inspect output.

Parameters:

  • attributes (Array<Symbol, String>)

    One or more attribute names



71
72
73
# File 'lib/auth/sanitizer/filtered_attributes.rb', line 71

def filtered_attributes(*attributes)
  ClassMethods.filtered_attributes(self, *attributes)
end